#!/usr/bin/env node
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateRankData = generateRankData;
exports.generateFlushData = generateFlushData;

var _fs = require('fs');

var _utils = require('../utils');

var _rank = require('../rank');

var output = process.argv[2];
var data = JSON.stringify({
  rank: generateRankData(),
  flush: generateFlushData()
});

(0, _fs.writeFile)(output, data, 'utf8', function (err) {
  if (err) throw err;
  console.log((data.length / 1024 / 1024).toFixed(2) + 'mb written to ' + output);
});

function generateRankData() {
  var data = {};
  for (var a = 0; a !== _utils.CARD_VALUES.length; a++) {
    for (var b = 0; b !== _utils.CARD_VALUES.length; b++) {
      for (var c = 0; c !== _utils.CARD_VALUES.length; c++) {
        for (var d = 0; d !== _utils.CARD_VALUES.length; d++) {
          for (var e = 0; e !== _utils.CARD_VALUES.length; e++) {
            for (var f = 0; f !== _utils.CARD_VALUES.length; f++) {
              for (var g = 0; g !== _utils.CARD_VALUES.length; g++) {
                if (a < b || b < c || c < d || d < e || e < f || f < g) {
                  continue;
                }
                var values = [_utils.CARD_VALUES[a], _utils.CARD_VALUES[b], _utils.CARD_VALUES[c], _utils.CARD_VALUES[d], _utils.CARD_VALUES[e], _utils.CARD_VALUES[f], _utils.CARD_VALUES[g]];
                data[values.join('')] = (0, _rank.rankValues)(values);
              }
            }
          }
        }
      }
    }
  }
  return data;
}

function generateFlushData() {
  var data = {};
  for (var a = 0; a !== _utils.CARD_SUITS.length; a++) {
    for (var b = 0; b !== _utils.CARD_SUITS.length; b++) {
      for (var c = 0; c !== _utils.CARD_SUITS.length; c++) {
        for (var d = 0; d !== _utils.CARD_SUITS.length; d++) {
          for (var e = 0; e !== _utils.CARD_SUITS.length; e++) {
            for (var f = 0; f !== _utils.CARD_SUITS.length; f++) {
              for (var g = 0; g !== _utils.CARD_SUITS.length; g++) {
                var key = [_utils.CARD_SUITS[a], _utils.CARD_SUITS[b], _utils.CARD_SUITS[c], _utils.CARD_SUITS[d], _utils.CARD_SUITS[e], _utils.CARD_SUITS[f], _utils.CARD_SUITS[g]].sort().join('');
                data[key] = (0, _rank.getFlush)(key);
              }
            }
          }
        }
      }
    }
  }
  return data;
}